@@ -1,3 +1,4 @@
+from ._bot_package_path import _set_bot_package_path
 from .arena import *
 from .channel import *
 from twitchbot.api.chatters import *
@@ -30,20 +31,6 @@ from .poll import *
 from .event_util import *
 from .extra_configs import *
 from .pubsub import *
-from . import builtin_commands
-from . import builtin_mods
 
-BOT_VERSION = (1, 17, 6)  # keep in sync with version in setup.py:11
-
-import os
-
-load_commands_from_directory(os.path.join(__path__[0], 'builtin_commands'))
-
-load_mods_from_directory(os.path.join(__path__[0], 'builtin_mods'))
-load_mods_from_directory(os.path.abspath(cfg.mods_folder))
-
-ensure_mods_folder_exists()
-ensure_commands_folder_exists()
-
-load_commands_from_directory(os.path.abspath(cfg.commands_folder))
-start_command_server()
+BOT_VERSION = (1, 18, 0)  # keep in sync with version in setup.py:11
+_set_bot_package_path(__path__[0])
